"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinaryReader = void 0;
const buffer_1 = require("buffer");
const utils_1 = require("./utils");
// BinaryReader provides the inverse of BinaryWriter
// Numbers are encoded as big endian
class BinaryReader {
    constructor(arrayBuffer) {
        this._buffer = buffer_1.Buffer.from(arrayBuffer);
        this._offset = 0;
    }
    readUint8() {
        const tmp = this._buffer.readUint8(this._offset);
        this._offset += 1;
        return tmp;
    }
    readUint16() {
        const tmp = this._buffer.readUint16BE(this._offset);
        this._offset += 2;
        return tmp;
    }
    readUint32() {
        const tmp = this._buffer.readUint32BE(this._offset);
        this._offset += 4;
        return tmp;
    }
    readUint64() {
        const tmp = this._buffer.readBigUInt64BE(this._offset);
        this._offset += 8;
        return tmp;
    }
    readUint8Array(length) {
        const tmp = this._buffer.subarray(this._offset, this._offset + length);
        this._offset += length;
        return new Uint8Array(tmp);
    }
    readHex(length) {
        return (0, utils_1.uint8ArrayToHex)(this.readUint8Array(length));
    }
    readString(length) {
        const tmp = this._buffer
            .subarray(this._offset, this._offset + length)
            .toString();
        this._offset += length;
        return tmp;
    }
}
exports.BinaryReader = BinaryReader;
