"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EthCallWithFinalityQueryResponse = exports.EthCallWithFinalityQueryRequest = void 0;
const BinaryReader_1 = require("./BinaryReader");
const BinaryWriter_1 = require("./BinaryWriter");
const ethCall_1 = require("./ethCall");
const request_1 = require("./request");
const utils_1 = require("./utils");
class EthCallWithFinalityQueryRequest {
    constructor(blockId, finality, callData) {
        this.callData = callData;
        this.blockId = (0, ethCall_1.parseBlockId)(blockId);
        this.finality = finality;
    }
    type() {
        return request_1.ChainQueryType.EthCallWithFinality;
    }
    serialize() {
        const writer = new BinaryWriter_1.BinaryWriter()
            .writeUint32(this.blockId.length)
            .writeUint8Array(Buffer.from(this.blockId))
            .writeUint32(this.finality.length)
            .writeUint8Array(Buffer.from(this.finality))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = (0, utils_1.hexToUint8Array)(data);
            writer
                .writeUint8Array((0, utils_1.hexToUint8Array)(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
    static from(bytes) {
        const reader = new BinaryReader_1.BinaryReader((0, utils_1.coalesceUint8Array)(bytes));
        return this.fromReader(reader);
    }
    static fromReader(reader) {
        const blockTagLength = reader.readUint32();
        const blockTag = reader.readString(blockTagLength);
        const finalityLength = reader.readUint32();
        const finality = reader.readString(finalityLength);
        if (finality != "finalized" && finality != "safe") {
            throw new Error(`Unsupported finality: ${finality}`);
        }
        const callDataLength = reader.readUint8();
        const callData = [];
        for (let idx = 0; idx < callDataLength; idx++) {
            const to = reader.readHex(20);
            const dataLength = reader.readUint32();
            const data = reader.readHex(dataLength);
            callData.push({ to, data });
        }
        return new EthCallWithFinalityQueryRequest(blockTag, finality, callData);
    }
}
exports.EthCallWithFinalityQueryRequest = EthCallWithFinalityQueryRequest;
class EthCallWithFinalityQueryResponse extends ethCall_1.EthCallQueryResponse {
    type() {
        return request_1.ChainQueryType.EthCallWithFinality;
    }
    static from(bytes) {
        const reader = new BinaryReader_1.BinaryReader((0, utils_1.coalesceUint8Array)(bytes));
        return this.fromReader(reader);
    }
    static fromReader(reader) {
        const queryResponse = ethCall_1.EthCallQueryResponse.fromReader(reader);
        return new EthCallWithFinalityQueryResponse(queryResponse.blockNumber, queryResponse.blockHash, queryResponse.blockTime, queryResponse.results);
    }
}
exports.EthCallWithFinalityQueryResponse = EthCallWithFinalityQueryResponse;
