"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sign = exports.signaturesToEvmStruct = exports.coalesceUint8Array = exports.uint8ArrayToHex = exports.hexToUint8Array = exports.isValidHexString = void 0;
const buffer_1 = require("buffer");
const elliptic = __importStar(require("elliptic"));
function isValidHexString(s) {
    return /^(0x)?[0-9a-fA-F]+$/.test(s);
}
exports.isValidHexString = isValidHexString;
function hexToUint8Array(s) {
    if (!isValidHexString(s)) {
        throw new Error(`${s} is not hex`);
    }
    if (s.startsWith("0x")) {
        s = s.slice(2);
    }
    s.padStart(s.length + (s.length % 2), "0");
    return new Uint8Array(buffer_1.Buffer.from(s, "hex"));
}
exports.hexToUint8Array = hexToUint8Array;
function uint8ArrayToHex(b) {
    return `0x${buffer_1.Buffer.from(b).toString("hex")}`;
}
exports.uint8ArrayToHex = uint8ArrayToHex;
function coalesceUint8Array(b) {
    return typeof b === "string" ? hexToUint8Array(b) : b;
}
exports.coalesceUint8Array = coalesceUint8Array;
function signaturesToEvmStruct(signatures) {
    return signatures.map((s) => ({
        r: `0x${s.substring(0, 64)}`,
        s: `0x${s.substring(64, 128)}`,
        v: `0x${(parseInt(s.substring(128, 130), 16) + 27).toString(16)}`,
        guardianIndex: `0x${s.substring(130, 132)}`,
    }));
}
exports.signaturesToEvmStruct = signaturesToEvmStruct;
/**
 * @param key Private key used to sign `data`
 * @param data Data for signing
 * @returns ECDSA secp256k1 signature
 */
function sign(key, data) {
    var _a;
    const ec = new elliptic.ec("secp256k1");
    const keyPair = ec.keyFromPrivate(key);
    const signature = keyPair.sign(data, { canonical: true });
    const packed = signature.r.toString("hex").padStart(64, "0") +
        signature.s.toString("hex").padStart(64, "0") +
        buffer_1.Buffer.from([(_a = signature.recoveryParam) !== null && _a !== void 0 ? _a : 0]).toString("hex");
    return packed;
}
exports.sign = sign;
