import { BinaryReader } from "./BinaryReader";
import { BinaryWriter } from "./BinaryWriter";
import { EthCallQueryResponse, parseBlockId, } from "./ethCall";
import { ChainQueryType } from "./request";
import { coalesceUint8Array, hexToUint8Array } from "./utils";
export class EthCallWithFinalityQueryRequest {
    constructor(blockId, finality, callData) {
        this.callData = callData;
        this.blockId = parseBlockId(blockId);
        this.finality = finality;
    }
    type() {
        return ChainQueryType.EthCallWithFinality;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint32(this.blockId.length)
            .writeUint8Array(Buffer.from(this.blockId))
            .writeUint32(this.finality.length)
            .writeUint8Array(Buffer.from(this.finality))
            .writeUint8(this.callData.length);
        this.callData.forEach(({ to, data }) => {
            const dataArray = hexToUint8Array(data);
            writer
                .writeUint8Array(hexToUint8Array(to))
                .writeUint32(dataArray.length)
                .writeUint8Array(dataArray);
        });
        return writer.data();
    }
    static from(bytes) {
        const reader = new BinaryReader(coalesceUint8Array(bytes));
        return this.fromReader(reader);
    }
    static fromReader(reader) {
        const blockTagLength = reader.readUint32();
        const blockTag = reader.readString(blockTagLength);
        const finalityLength = reader.readUint32();
        const finality = reader.readString(finalityLength);
        if (finality != "finalized" && finality != "safe") {
            throw new Error(`Unsupported finality: ${finality}`);
        }
        const callDataLength = reader.readUint8();
        const callData = [];
        for (let idx = 0; idx < callDataLength; idx++) {
            const to = reader.readHex(20);
            const dataLength = reader.readUint32();
            const data = reader.readHex(dataLength);
            callData.push({ to, data });
        }
        return new EthCallWithFinalityQueryRequest(blockTag, finality, callData);
    }
}
export class EthCallWithFinalityQueryResponse extends EthCallQueryResponse {
    type() {
        return ChainQueryType.EthCallWithFinality;
    }
    static from(bytes) {
        const reader = new BinaryReader(coalesceUint8Array(bytes));
        return this.fromReader(reader);
    }
    static fromReader(reader) {
        const queryResponse = EthCallQueryResponse.fromReader(reader);
        return new EthCallWithFinalityQueryResponse(queryResponse.blockNumber, queryResponse.blockHash, queryResponse.blockTime, queryResponse.results);
    }
}
