import { QueryProxyQueryResponse, QueryRequest } from "../query";
/**
 * Usage:
 *
 * ```js
 * const mock = new QueryProxyMock({
 *   2: "http://localhost:8545",
 * });
 * ```
 *
 * If you are running an Anvil fork like
 *
 * ```bash
 * anvil -f https://ethereum-goerli.publicnode.com
 * ```
 *
 * You can use the following command to switch the guardian address to the devnet / mock guardian
 *
 * Where the `-a` parameter is the core bridge address on that chain
 *
 * https://docs.wormhole.com/wormhole/reference/constants#core-contracts
 *
 * ```bash
 * npx \@wormhole-foundation/wormhole-cli evm hijack -a 0x706abc4E45D419950511e474C7B9Ed348A4a716c -g 0xbeFA429d57cD18b7F8A4d91A2da9AB4AF05d0FBe
 * ```
 */
export declare class QueryProxyMock {
    rpcMap: {
        [chainId: number]: string;
    };
    mockPrivateKeys: string[];
    constructor(rpcMap: {
        [chainId: number]: string;
    }, mockPrivateKeys?: string[]);
    sign(serializedResponse: Uint8Array): string[];
    /**
     * Usage:
     *
     * ```js
     * const { bytes, signatures } = await mock.mock(new QueryRequest(nonce, [
     *   new PerChainQueryRequest(
     *     wormholeChainId,
     *     new EthCallQueryRequest(blockNumber, [
     *       { to: contract, data: abiEncodedData },
     *     ])
     *   ),
     * ]));
     * ```
     *
     * @param queryRequest an instance of the `QueryRequest` class
     * @returns a promise result matching the query proxy's query response
     */
    mock(queryRequest: QueryRequest): Promise<QueryProxyQueryResponse>;
}
